[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- pysmug.smugsync.SmugSync: Synchronize a local directory with SmugMug albums.
- object: The most base type
  - exceptions.BaseException: Common base class for all exceptions
    - exceptions.Exception: Common base class for all non-exit exceptions.
      - pysmug.smugmug.SmugMugException: Representation of a SmugMug exception.
        - pysmug.smugmug.HTTPException: An exception thrown during http(s) communication.
  - pysmug.smugmug.SmugBase: Abstract functionality for SmugMug API clients.
    - pysmug.smugmug.SmugBatch: Batching version of a SmugMug client.
    - pysmug.smugmug.SmugMug: Serial version of a SmugMug client.